@@ -1,17 +1,16 @@
 import json
 import logging
 
-from fastapi import Request
 from fastapi.exceptions import RequestValidationError
-from fastapi.responses import JSONResponse
 
 from web_error.error import HttpException
+from web_error.handler import starlette
 
 
 logger = logging.getLogger(__name__)
 
 
-def exception_handler(request: Request, exc: Exception):
+def exception_handler(request: starlette.Request, exc: Exception):
     status = 500
     message = "Unhandled exception occured."
     response = {
@@ -32,7 +31,22 @@ def exception_handler(request: Request, exc: Exception):
     if status >= 500:
         logger.exception(message, exc_info=(type(exc), exc, exc.__traceback__))
 
-    return JSONResponse(
+    return starlette.JSONResponse(
         status_code=status,
         content=response,
     )
+
+
+def generate_handler_with_cors(
+    allow_origins=None,
+    allow_credentials=True,
+    allow_methods=None,
+    allow_headers=None,
+):
+    return starlette.generate_handler_with_cors(
+        allow_origins=allow_origins,
+        allow_credentials=allow_credentials,
+        allow_methods=allow_methods,
+        allow_headers=allow_headers,
+        _exception_handler=exception_handler,
+    )
